@@ -29,6 +29,20 @@ int fstat(int fd, struct stat *buf)
 }
 libc_hidden_def(fstat)
 
+#elif __NR_statx && defined __UCLIBC_HAVE_STATX__
+# include <fcntl.h>
+# include <statx_cp.h>
+
+int fstat(int fd, struct stat *buf)
+{
+      struct statx tmp;
+      int rc = INLINE_SYSCALL (statx, 5, fd, "", AT_EMPTY_PATH,
+                               STATX_BASIC_STATS, &tmp);
+      if (rc == 0)
+        __cp_stat_statx ((struct stat *)buf, &tmp);
+}
+libc_hidden_def(fstat)
+
 #elif defined __NR_fstat
 int fstat(int fd, struct stat *buf)
 {
@@ -57,7 +71,7 @@ int fstat(int fd, struct stat *buf)
 libc_hidden_def(fstat)
 #endif
 
-# if ! defined __NR_fstat64
+# if ! defined __NR_fstat64 && ! defined __UCLIBC_HAVE_STATX__
 strong_alias_untyped(fstat,fstat64)
 libc_hidden_def(fstat64)
 #endif
