@@ -29,6 +29,23 @@ int lstat64(const char *file_name, struct stat64 *buf)
 }
 libc_hidden_def(lstat64)
 
+#elif defined __NR_statx && defined __UCLIBC_HAVE_STATX__
+# include <fcntl.h>
+# include <statx_cp.h>
+
+int lstat64(const char *file_name, struct stat64 *buf)
+{
+      struct statx tmp;
+      int rc = INLINE_SYSCALL (statx, 5, AT_FDCWD, file_name,
+                               AT_NO_AUTOMOUNT | AT_SYMLINK_NOFOLLOW,
+                               STATX_BASIC_STATS, &tmp);
+      if (rc == 0)
+        __cp_stat64_statx ((struct stat64 *)buf, &tmp);
+
+      return rc;
+}
+libc_hidden_def(lstat64)
+
 /* For systems which have both, prefer the old one */
 #elif defined __NR_lstat64
 # include "xstatconv.h"
