@@ -8,7 +8,10 @@
 #undef __UCLIBC_ABORT_INSTRUCTION__
 
 /* can your target use syscall6() for mmap ? */
-#undef __UCLIBC_MMAP_HAS_6_ARGS__
+#define __UCLIBC_MMAP_HAS_6_ARGS__
+
+/* does your target use statx */
+#undef __UCLIBC_HAVE_STATX__
 
 #define __UCLIBC_SYSCALL_ALIGN_64BIT__
 
