@@ -74,8 +74,8 @@ struct stat
     __time_t st_ctime;			/* Time of last status change.  */
     unsigned long int st_ctimensec;	/* Nsecs of last status change.  */
 #endif
-    unsigned long int __unused4;
-    unsigned long int __unused5;
+    unsigned long int __uclibc_unused4;
+    unsigned long int __uclibc_unused5;
   };
 
 #ifdef __USE_LARGEFILE64
@@ -114,8 +114,8 @@ struct stat64
     __time_t st_ctime;			/* Time of last status change.  */
     unsigned long int st_ctimensec;	/* Nsecs of last status change.  */
 #endif
-    unsigned long int __unused4;
-    unsigned long int __unused5;
+    unsigned long int __uclibc_unused4;
+    unsigned long int __uclibc_unused5;
   };
 #endif
 
